==> haskell-either-4.4.1.1-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1.1
id: either-4.4.1.1-ILupdecl1293Cc0SGnn407
key: either-4.4.1.1-ILupdecl1293Cc0SGnn407
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
abi: 8eaa19f4c658d2153db811c91cff569e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/either-4.4.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/either-4.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/either-4.4.1.1
hs-libraries: HSeither-4.4.1.1-ILupdecl1293Cc0SGnn407
depends:
    MonadRandom-0.5.1-4pilVmquiIE6YjsysdbKdo base-4.9.1.0
    bifunctors-5.4.2-8sihn7PNvccAEMEjqQmBaw
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    free-4.12.4-3GdOADSpSgmCdK4GoN8xLg
    mmorph-1.1.0-BKb9vDVN1ubG7npUIlJCzH
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    profunctors-5.2.1-5x71Wug1TnuAdpWqS2CUNd
    semigroupoids-5.2.1-AZdsYazgWLZ9acFdqW12To
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-4.4.1.1-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1.1
id: either-4.4.1.1-DPnDxHcBTmhFK5NMlOpJf2
key: either-4.4.1.1-DPnDxHcBTmhFK5NMlOpJf2
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
abi: 95ba5f52c5f78e6a1682b3fbd886236e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/either-4.4.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/either-4.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/either-4.4.1.1
hs-libraries: HSeither-4.4.1.1-DPnDxHcBTmhFK5NMlOpJf2
depends:
    MonadRandom-0.5.1-4pilVmquiIE6YjsysdbKdo base-4.9.1.0
    bifunctors-5.4.2-Hs7FNb9nROsIXkBtaUQIi2
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    free-4.12.4-I4KojKWmMWdKgxeJVSIbRj
    mmorph-1.1.0-BKb9vDVN1ubG7npUIlJCzH
    monad-control-1.0.2.2-FLdbJMBsCl8Hxe7Woti7SW
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    profunctors-5.2.1-8jkaYZ4vYzz4yY8hupumkp
    semigroupoids-5.2.1-5FkqrM8Y49T6SPr4eeeHyr
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
